@@ -2,6 +2,7 @@ package PlugAuth::Plugin::DBIAuth;
 
 use strict;
 use warnings;
+use 5.010;
 use DBI;
 use Log::Log4perl qw/:easy/;
 use Role::Tiny::With;
@@ -11,7 +12,7 @@ with 'PlugAuth::Role::Plugin';
 with 'PlugAuth::Role::Auth';
 
 # ABSTRACT: DBI Authentication back end for PlugAuth
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 sub init
@@ -48,9 +49,9 @@ sub check_credentials
     $self->{check_credentials}->finish;
     if($encrypted)
     {
-      return 1 if crypt($pass, $encrypted) eq $encrypted;
+      my $tmp = crypt($pass, $encrypted);
+      return 1 if (defined $tmp) && ($tmp eq $encrypted);
       
-        $DB::single = 1;
       if($encrypted =~ /^\$(\w+)\$/)
       {
         return 1 if $1 eq 'apr1' && apache_md5_crypt( $pass, $encrypted ) eq $encrypted;
@@ -166,7 +167,7 @@ PlugAuth::Plugin::DBIAuth - DBI Authentication back end for PlugAuth
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -293,8 +294,6 @@ Given a new plain text password, return the encrypted version.
 L<DBI>,
 L<PlugAuth>
 
-=cut
-
 =head1 AUTHOR
 
 Graham Ollis <gollis@sesda3.com>
